==> react-router-query-params-1.0.0.tgz: package/es/index.js <==
import _defineProperty from 'babel-runtime/helpers/defineProperty';
import _Object$getPrototypeOf from 'babel-runtime/core-js/object/get-prototype-of';
import _classCallCheck from 'babel-runtime/helpers/classCallCheck';
import _createClass from 'babel-runtime/helpers/createClass';
import _possibleConstructorReturn from 'babel-runtime/helpers/possibleConstructorReturn';
import _inherits from 'babel-runtime/helpers/inherits';
import _extends from 'babel-runtime/helpers/extends';
import _Object$keys from 'babel-runtime/core-js/object/keys';
import React, { PureComponent } from 'react';
import PropTypes from 'prop-types';
import { Redirect, withRouter } from 'react-router-dom';
import queryString from 'query-string';
import getDisplayName from 'react-display-name';

import { isObject, assert } from './utils';

export default function withQueryParams() {
  var _ref = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {},
      keys = _ref.keys,
      _ref$stripUnknownKeys = _ref.stripUnknownKeys,
      stripUnknownKeys = _ref$stripUnknownKeys === undefined ? false : _ref$stripUnknownKeys,
      queryStringOptions = _ref.queryStringOptions;

  if (keys && stripUnknownKeys) {
    assert(_Object$keys(keys).length > 0, 'at least one query param key must be configured');
  }

  if (keys) {
    _Object$keys(keys).forEach(function (key) {
      assert(keys[key].default, 'Missing default value for key ' + key);
      assert(typeof keys[key].default === 'string' || typeof keys[key].default === 'function', '\'default\' for key ' + key + ' must be a string or a function');
      assert(keys[key].validate, 'Missing validate function for key ' + key);
      assert(typeof keys[key].validate === 'function', '\'validate\' for ' + key + ' must be a function');
    });
  }

  var QUERYPARAMS_OPTIONS = _extends({
    arrayFormat: 'none' }, queryStringOptions);

  return function (Wrapped) {
    var WithQueryParams = function (_PureComponent) {
      _inherits(WithQueryParams, _PureComponent);

      function WithQueryParams() {
        var _ref2;

        var _temp, _this, _ret;

        _classCallCheck(this, WithQueryParams);

        for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
          args[_key] = arguments[_key];
        }

        return _ret = (_temp = (_this = _possibleConstructorReturn(this, (_ref2 = WithQueryParams.__proto__ || _Object$getPrototypeOf(WithQueryParams)).call.apply(_ref2, [this].concat(args))), _this), _initialiseProps.call(_this), _temp), _possibleConstructorReturn(_this, _ret);
      }

      _createClass(WithQueryParams, [{
        key: 'render',
        value: function render() {
          var _this2 = this;

          var location = this.props.location;

          var queryParams = queryString.parse(location.search, QUERYPARAMS_OPTIONS);

          var newQueryParams = keys ? _Object$keys(keys).reduce(function (acc, paramName) {
            var defaultConf = keys[paramName].default;
            var defaultValue = typeof defaultConf === 'function' ? defaultConf(queryParams[paramName], _this2.props) : defaultConf;

            return _extends({}, acc, _defineProperty({}, paramName, keys[paramName].validate(queryParams[paramName], _this2.props) ? queryParams[paramName] : defaultValue));
          }, {}) : queryParams;

          var allParams = stripUnknownKeys ? newQueryParams : _extends({}, queryParams, newQueryParams);

          var searchString = queryString.stringify(allParams, QUERYPARAMS_OPTIONS);

          if (location.search.replace('?', '') !== searchString) {
            return React.createElement(Redirect, { to: { pathname: location.pathname, search: searchString } });
          }

          var wrappedProps = {
            location: location,
            setQueryParam: this.setQueryParam,
            queryParams: allParams
          };

          return React.createElement(Wrapped, _extends({}, this.props, wrappedProps));
        }
      }]);

      return WithQueryParams;
    }(PureComponent);

    WithQueryParams.displayName = 'withQueryParams(' + getDisplayName(Wrapped) + ')';
    WithQueryParams.propTypes = {
      location: PropTypes.shape({
        search: PropTypes.string,
        pathname: PropTypes.string
      }).isRequired,
      history: PropTypes.shape({
        push: PropTypes.func.isRequired,
        createHref: PropTypes.func.isRequired
      }).isRequired
    };

    var _initialiseProps = function _initialiseProps() {
      var _this3 = this;

      this.setQueryParam = function () {
        var obj = isObject(arguments.length <= 0 ? undefined : arguments[0]) ? arguments.length <= 0 ? undefined : arguments[0] : _defineProperty({}, arguments.length <= 0 ? undefined : arguments[0], arguments.length <= 1 ? undefined : arguments[1]);

        _this3.setQueryParams(obj);
      };

      this.setQueryParams = function (obj) {
        var _props = _this3.props,
            location = _props.location,
            history = _props.history;


        var to = history.createHref({
          pathname: location.pathname,
          search: queryString.stringify(_extends({}, queryString.parse(location.search, QUERYPARAMS_OPTIONS), obj), QUERYPARAMS_OPTIONS)
        });

        history.push(to);
      };
    };

    return withRouter(WithQueryParams);
  };
}

==> react-router-query-params-1.0.2.tgz: package/es/index.js <==
import _defineProperty from 'babel-runtime/helpers/defineProperty';
import _Object$getPrototypeOf from 'babel-runtime/core-js/object/get-prototype-of';
import _classCallCheck from 'babel-runtime/helpers/classCallCheck';
import _createClass from 'babel-runtime/helpers/createClass';
import _possibleConstructorReturn from 'babel-runtime/helpers/possibleConstructorReturn';
import _inherits from 'babel-runtime/helpers/inherits';
import _extends from 'babel-runtime/helpers/extends';
import _Object$keys from 'babel-runtime/core-js/object/keys';
import React, { PureComponent } from 'react';
import PropTypes from 'prop-types';
import { Redirect, withRouter } from 'react-router-dom';
import queryString from 'query-string';
import getDisplayName from 'react-display-name';

import { assert } from './utils';

export default function withQueryParams() {
  var _ref = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {},
      keys = _ref.keys,
      _ref$stripUnknownKeys = _ref.stripUnknownKeys,
      stripUnknownKeys = _ref$stripUnknownKeys === undefined ? false : _ref$stripUnknownKeys,
      queryStringOptions = _ref.queryStringOptions;

  if (keys && stripUnknownKeys) {
    assert(_Object$keys(keys).length > 0, 'at least one query param key must be configured');
  }

  if (keys) {
    _Object$keys(keys).forEach(function (key) {
      assert(keys[key].validate, 'Missing validate function for key ' + key);
      assert(typeof keys[key].validate === 'function', '\'validate\' for ' + key + ' must be a function');
    });
  }

  var QUERYPARAMS_OPTIONS = _extends({
    arrayFormat: 'none' }, queryStringOptions);

  return function (Wrapped) {
    var WithQueryParams = function (_PureComponent) {
      _inherits(WithQueryParams, _PureComponent);

      function WithQueryParams() {
        var _ref2;

        var _temp, _this, _ret;

        _classCallCheck(this, WithQueryParams);

        for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
          args[_key] = arguments[_key];
        }

        return _ret = (_temp = (_this = _possibleConstructorReturn(this, (_ref2 = WithQueryParams.__proto__ || _Object$getPrototypeOf(WithQueryParams)).call.apply(_ref2, [this].concat(args))), _this), _this.setQueryParams = function (obj) {
          var _this$props = _this.props,
              location = _this$props.location,
              history = _this$props.history;


          var to = history.createHref({
            pathname: location.pathname,
            search: queryString.stringify(_extends({}, queryString.parse(location.search, QUERYPARAMS_OPTIONS), obj), QUERYPARAMS_OPTIONS)
          });

          history.push(to);
        }, _temp), _possibleConstructorReturn(_this, _ret);
      }

      _createClass(WithQueryParams, [{
        key: 'render',
        value: function render() {
          var _this2 = this;

          var location = this.props.location;

          var queryParams = queryString.parse(location.search, QUERYPARAMS_OPTIONS);

          var newQueryParams = keys ? _Object$keys(keys).reduce(function (acc, paramName) {
            var defaultConf = keys[paramName].default;
            var defaultValue = typeof defaultConf === 'function' ? defaultConf(queryParams[paramName], _this2.props) : defaultConf;

            return _extends({}, acc, _defineProperty({}, paramName, keys[paramName].validate(queryParams[paramName], _this2.props) ? queryParams[paramName] : defaultValue));
          }, {}) : queryParams;

          var allParams = stripUnknownKeys ? newQueryParams : _extends({}, queryParams, newQueryParams);

          var searchString = queryString.stringify(allParams, QUERYPARAMS_OPTIONS);

          if (location.search.replace('?', '') !== searchString) {
            return React.createElement(Redirect, { to: { pathname: location.pathname, search: searchString } });
          }

          var wrappedProps = {
            location: location,
            setQueryParams: this.setQueryParams,
            queryParams: allParams
          };

          return React.createElement(Wrapped, _extends({}, this.props, wrappedProps));
        }
      }]);

      return WithQueryParams;
    }(PureComponent);

    WithQueryParams.displayName = 'withQueryParams(' + getDisplayName(Wrapped) + ')';
    WithQueryParams.propTypes = {
      location: PropTypes.shape({
        search: PropTypes.string,
        pathname: PropTypes.string
      }).isRequired,
      history: PropTypes.shape({
        push: PropTypes.func.isRequired,
        createHref: PropTypes.func.isRequired
      }).isRequired
    };


    return withRouter(WithQueryParams);
  };
}
